@@ -1,24 +1,28 @@
 import os
-from typing import List, Optional
+from typing import List
 
+from docrunner.utils.language import create_language_environment
+
+from ..models.options import Options
 from ..utils.file import get_code_from_markdown, write_file
 
 
-def create_javascript_environment(directory_path: Optional[str] = None) -> str:
-    if directory_path == None:
-        directory_path = './docrunner-build-js'
-        if not os.path.exists(directory_path):
-            os.mkdir(directory_path)
-
-    return directory_path
-
-
 def run_javascript(
-    directory_path: Optional[str] = None,
-    markdown_path: Optional[str] = None,
-    multi_file: Optional[bool] = None,
-    startup_command: Optional[str] = None,
+    options: Options
 ):
+    """Runs all javascript code within a markdown '.md' file
+
+    Parameters
+    ----------
+    options : Options
+        Docrunner options
+    """
+
+    markdown_path = options.markdown_path
+    directory_path = options.directory_path
+    startup_command = options.startup_command
+    multi_file = options.multi_file
+    
     code_snippets = get_code_from_markdown(
         language='javascript',
         markdown_path=markdown_path,
@@ -26,7 +30,8 @@ def run_javascript(
     if not code_snippets:
         return None
 
-    directory_path = create_javascript_environment(
+    directory_path = create_language_environment(
+        language='js',
         directory_path=directory_path,
     )
 
