@@ -1,28 +1,26 @@
-from ..utils.file import get_code_from_markdown, write_file
 import os
-import platform
-from pathlib import Path
-from typing import List, Optional
-import subprocess
+from typing import List
 
-
-def create_python_environment(env_path: Optional[str] = None) -> str:
-    if env_path == None:
-        directory_path = './docrunner-build-py'
-        if not os.path.exists(directory_path):
-            os.mkdir(directory_path)
-    else:
-        directory_path = str(Path(env_path).parent)
-
-    return directory_path
+from ..models.options import Options
+from ..utils.file import get_code_from_markdown, write_file
+from ..utils.language import create_language_environment
 
 
 def run_python(
-    env_path: Optional[str] = None,
-    startup_command: Optional[str] = None,
-    markdown_path: Optional[str] = None,
-    multi_file: Optional[bool] = None,
+    options: Options
 ):
+    """Runs all python code within a markdown '.md' file
+
+    Parameters
+    ----------
+    options : Options
+        Docrunner options
+    """
+    markdown_path = options.markdown_path
+    directory_path = options.directory_path
+    multi_file = options.multi_file
+    startup_command = options.startup_command
+
     code_snippets = get_code_from_markdown(
         language='python',
         markdown_path=markdown_path,
@@ -30,9 +28,11 @@ def run_python(
     if not code_snippets:
         return None
 
-    directory_path = create_python_environment(
-        env_path=env_path
+    directory_path = create_language_environment(
+        language='py',
+        directory_path=directory_path
     )
+    
     filepath: str = None
     if multi_file:
         filepaths: List[str] = []
@@ -51,16 +51,6 @@ def run_python(
             lines=all_lines,
         )
 
-    if env_path:
-        operating_system = platform.system()
-        env_command: str = None
-        if operating_system == 'Windows':
-            env_command = f'{env_path}\\Scripts\\activate.bat'
-            subprocess.call(env_command)
-        elif operating_system == 'Linux':
-            env_command = f'source {env_path}/bin/activate'
-            os.system(env_command)
-
     if startup_command:
         startup_command = startup_command.replace('"', '')
         os.system(startup_command)
