@@ -1,19 +1,13 @@
 import os
 from pathlib import Path
-from typing import List, Optional
+from typing import List
 
+from docrunner.utils.language import create_language_environment
+
+from ..models.options import Options
 from ..utils.file import get_code_from_markdown, write_file
 
 
-def create_typescript_environment(directory_path: Optional[str] = None) -> str:
-    if directory_path == None:
-        directory_path = './docrunner-build-ts'
-        if not os.path.exists(directory_path):
-            os.mkdir(directory_path)
-
-    return directory_path
-
-
 def compile_typescript(filepath: str) -> int:
     directory_path = str(Path(filepath).parent)
     compile_command = f'tsc {filepath}'
@@ -32,11 +26,21 @@ def compile_typescript(filepath: str) -> int:
 
 
 def run_typescript(
-    directory_path: Optional[str] = None,
-    markdown_path: Optional[str] = None,
-    multi_file: Optional[bool] = None,
-    startup_command: Optional[str] = None,
+    options: Options
 ):
+    """Runs all typescript code within a markdown '.md' file
+
+    Parameters
+    ----------
+    options : Options
+        Docrunner options
+    """
+
+    markdown_path = options.markdown_path
+    directory_path = options.directory_path
+    startup_command = options.startup_command
+    multi_file = options.multi_file
+    
     code_snippets = get_code_from_markdown(
         language='typescript',
         markdown_path=markdown_path,
@@ -44,7 +48,8 @@ def run_typescript(
     if not code_snippets:
         return None
 
-    directory_path = create_typescript_environment(
+    directory_path = create_language_environment(
+        language='ts',
         directory_path=directory_path,
     )
 
