@@ -1,9 +1,11 @@
 import os
-from io import TextIOWrapper
-from typing import List, Optional, Union
-import typer
 import re
+from io import TextIOWrapper
+from pathlib import Path
+from typing import List, Optional
+
 import requests
+import typer
 
 LANGUAGE_ABBREV_MAPPING = {
     'python': [
@@ -18,6 +20,9 @@ LANGUAGE_ABBREV_MAPPING = {
         '```ts',
         '```typescript'
     ],
+    'dart': [
+        '```dart'
+    ]
 }
 
 
@@ -66,6 +71,18 @@ def validate_links(markdown_path: Optional[str] = None):
 
 
 def read_markdown(markdown_path: Optional[str] = None) -> Optional[List[str]]:
+    """Reads a markdown file and returns a list of lines
+
+    Parameters
+    ----------
+    markdown_path : Optional[str], optional
+        Path to the markdown '.md' file, by default None
+
+    Returns
+    -------
+    Optional[List[str]]
+        List of lines from markdown '.md' file
+    """
     if not markdown_path:
         markdown_path = './README.md'
     
@@ -90,7 +107,21 @@ def read_markdown(markdown_path: Optional[str] = None) -> Optional[List[str]]:
 def get_code_from_markdown(
     language: str,
     markdown_path: Optional[str] = None,
-) -> Union[List[str], None]:
+) -> Optional[List[str]]:
+    """Returns a list of code snippets of a certain `language`
+
+    Parameters
+    ----------
+    language : str
+        Name of the language
+    markdown_path : Optional[str], optional
+        Path to the markdown '.md' file, by default None
+
+    Returns
+    -------
+    Optional[List[str]]
+        List of string code snippets from markdown '.md' file
+    """
 
     markdown_lines = read_markdown(
         markdown_path=markdown_path,
@@ -140,12 +171,44 @@ def get_code_from_markdown(
     return code_snippets
 
 
-def write_file(filepath: str, lines: str) -> None:
+def write_file(filepath: str, lines: str, overwrite: Optional[bool] = None) -> None:
+    """Writes `lines` to a file located at `filepath`
+
+    Parameters
+    ----------
+    filepath : str
+        Filepath of file you want to write to
+    lines : str
+        String you want to write into file
+    overwrite : Optional[bool]
+        Whether the file should be overwritten if it already exists
+    """
+
+    if not overwrite:
+        overwrite = False
+
     main_file: TextIOWrapper = None
-    if os.path.exists(filepath):
-        main_file = open(filepath, mode='w+', encoding='utf-8')
-    else:
-        main_file = open(filepath, mode='x', encoding='utf-8')
+    try:
+        if os.path.exists(filepath):
+            if not overwrite:
+                typer.echo(
+                    typer.style(
+                        f'Error: file `{filepath}` already exists',
+                        fg=typer.colors.RED,
+                    ),
+                    err=True,
+                )
+            main_file = open(filepath, mode='w+', encoding='utf-8')
+        else:
+            main_file = open(filepath, mode='x', encoding='utf-8')
+    except FileNotFoundError as error:
+        typer.echo(
+            typer.style(
+                f'Error: folder `{Path(error.filename).parent}` not found', fg=typer.colors.RED
+            ),
+            err=True
+        )
+        return None
 
     main_file.write(lines)
     main_file.close()
